@@ -11,9 +11,10 @@
 from __future__ import absolute_import, print_function
 
 import os
-import pytest
 import shutil
 import tempfile
+
+import pytest
 from flask import Flask
 from invenio_db import InvenioDB
 from sqlalchemy_utils.functions import create_database, database_exists
@@ -26,13 +27,14 @@ def app(request):
     """Flask application fixture."""
     # Set temporary instance path for sqlite
     instance_path = tempfile.mkdtemp()
-    app = Flask('testapp', instance_path=instance_path)
+    app = Flask("testapp", instance_path=instance_path)
     InvenioDB(app)
     InvenioPIDStore(app)
 
     app.config.update(
         SQLALCHEMY_DATABASE_URI=os.environ.get(
-            'SQLALCHEMY_DATABASE_URI', 'sqlite:///test.db'),
+            "SQLALCHEMY_DATABASE_URI", "sqlite:///test.db"
+        ),
         TESTING=True,
     )
 
